@@ -48,8 +48,8 @@ class SearchWindow(QMainWindow, Ui_SearchWindow):
         super(SearchWindow, self).__init__(parent)
         self.setupUi(self)
         self.resultsWindow = ResultsWindow(self)
-        if os.path.isfile('/opt/RadiotimeToGo/radiotime_logo_400.png'):
-            pixmap = QPixmap('/opt/RadiotimeToGo/radiotime_logo_400.png')
+        if os.path.isfile('/opt/RadioTimeToGo/radiotime_logo_400.png'):
+            pixmap = QPixmap('/opt/RadioTimeToGo/radiotime_logo_400.png')
         else:
             pixmap = QPixmap('radiotime_logo_400.png')
 
